=============
Django-Twilio
=============

Integrate Twilio into your Django apps with ease.

.. image:: https://badge.fury.io/py/django-twilio.png
    :target: http://badge.fury.io/py/django-twilio
    :alt: PyPI version
.. image:: https://travis-ci.org/rdegges/django-twilio.png?branch=master
    :target: https://travis-ci.org/rdegges/django-twilio
    :alt: CI build
.. image:: https://readthedocs.org/projects/django-twilio/badge/?version=latest
    :target: https://readthedocs.org/projects/django-twilio/badge/?version=latest
    :alt: documentation build
.. image:: https://img.shields.io/pypi/pyversions/django-twilio.svg
    :target:  https://pypi.python.org/pypi/django-twilio/
    :alt: Python versions supported

Meta
----

* Author: Randall Degges
* Email:  rdegges@gmail.com
* Maintainer: Jason Held
* Email: jasonsheld@gmail.com
* Status: active development, stable, maintained

`Twilio <http://www.twilio.com/>`_ is a powerful HTTP API that allows you to
build powerful voice & SMS apps. The goal of this library is to help make
building telephony applications as simple as humanly possible with twilio.


User's Guide
------------


Version 0.9.0 supports twilio 6.x and django 1.8-2.0.

Version 0.9.2 has minimal py3.7 support and 0.9.2 & 0.9.3 also allows django 2.1

For legacy twilio (5.x SDK), please see the 0.8 version.


This part of the documentation contains an extensive walk through of
django-twilio. It begins with some background information about django-twilio,
then focuses on step-by-step integration of django-twilio into your existing
Django web applications.

.. toctree::
    :maxdepth: 2

    foreword
    install
    settings
    decorators
    requests
    views
    rest
    gotchas
    howto
    contribute
    contributors


Indices and Tables
------------------

The following is auto-generated documentation that can be used to quickly find
relevant parts of this documentation.

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
